@@ -1,6 +1,7 @@
 pub mod command;
 
 pub mod bool;
+pub mod decimal;
 pub mod dice;
 pub mod integer;
 #[cfg(feature = "uuid_crate")]
@@ -9,6 +10,7 @@ pub mod uuid;
 pub use command::Command as Random;
 
 pub use self::bool::SubCommand as RandomBool;
+pub use decimal::SubCommand as RandomDecimal;
 pub use dice::SubCommand as RandomDice;
 pub use integer::SubCommand as RandomInteger;
 #[cfg(feature = "uuid_crate")]
