@@ -65,11 +65,12 @@ async fn reject(args: CommandArgs, registry: &CommandRegistry) -> Result<OutputS
 #[cfg(test)]
 mod tests {
     use super::Reject;
+    use super::ShellError;
 
     #[test]
-    fn examples_work_as_expected() {
+    fn examples_work_as_expected() -> Result<(), ShellError> {
         use crate::examples::test as test_examples;
 
-        test_examples(Reject {})
+        Ok(test_examples(Reject {})?)
     }
 }
